@@ -34,14 +34,19 @@ define([
                 .addClass('widget-readout')
                 .attr('contentEditable', true)
                 .hide();
-
-            this.listenTo(this.model, 'change:slider_color', function(sender, value) {
+                
+            this.listenTo(this.model, 'change:slider_handleTextChangecolor', function(sender, value) {
                 this.$slider.find('a').css('background', value);
+            }, this);            
+            this.listenTo(this.model, 'change:description', function(sender, value) {
+                this.updateDescription();
             }, this);
+            
             this.$slider.find('a').css('background', this.model.get('slider_color'));
             
             // Set defaults.
             this.update();
+            this.updateDescription();
         },
 
         update_attr: function(name, value) {
@@ -64,6 +69,16 @@ define([
             }
         },
         
+        updateDescription: function(options) {
+            var description = this.model.get('description');
+            if (description.length === 0) {
+                this.$label.hide();
+            } else {
+                this.typeset(this.$label, description);
+                this.$label.show();
+            }
+        },
+        
         update : function(options){
             /**
              * Update the contents of this view
@@ -118,7 +133,7 @@ define([
                     // values for the range case are validated python-side in
                     // _Bounded{Int,Float}RangeWidget._validate
                     this.$slider.slider('option', 'values', value);
-                    this.$readout.text(value.join("-"));
+                    this.$readout.text(this.valueToString(value));
                 } else {
                     if(value > max) { 
                         value = max; 
@@ -127,7 +142,7 @@ define([
                         value = min; 
                     }
                     this.$slider.slider('option', 'value', value);
-                    this.$readout.text(value);
+                    this.$readout.text(this.valueToString(value));
                 }
 
                 if(this.model.get('value')!=value) {
@@ -153,14 +168,6 @@ define([
                         .addClass('widget-hbox');
                 }
 
-                var description = this.model.get('description');
-                if (description.length === 0) {
-                    this.$label.hide();
-                } else {
-                    this.typeset(this.$label, description);
-                    this.$label.show();
-                }
-                
                 var readout = this.model.get('readout');
                 if (readout) {
                     this.$readout.show();
@@ -171,9 +178,44 @@ define([
             return IntSliderView.__super__.update.apply(this);
         },
         
+        /**
+         * Write value to a string
+         * @param  {number|number[]} value
+         * @return {string}
+         */
+        valueToString: function(value) {
+            if (this.model.get('_range')) {
+                return value.join("-");
+            } else {
+                return String(value);
+            }
+        },
+        
+        /**
+         * Parse value from a string
+         * @param  {string} text
+         * @return {number|number[]} value
+         */
+        stringToValue: function(text) {
+            if (this.model.get("_range")) {
+                // range case
+                // ranges can be expressed either "val-val" or "val:val" (+spaces)
+                var match = this._range_regex.exec(text);
+                if (match) {
+                    return [this._parse_value(match[1]), this._parse_value(match[2])];
+                } else {
+                    return null;
+                }
+                
+            } else {
+                return this._parse_value(text);
+            }
+        },
+        
         events: {
             // Dictionary of events and their handlers.
-            "slide" : "handleSliderChange",
+            "slide": "handleSliderChange",
+            "slidestop": "handleSliderChanged",
             "blur [contentEditable=true]": "handleTextChange",
             "keydown [contentEditable=true]": "handleKeyDown"
         }, 
@@ -197,53 +239,44 @@ define([
              *
              * the step size is not enforced
              */
-
-            var text = this.$readout.text();
+            var value = this.stringToValue(this.$readout.text());
             var vmin = this.model.get('min');
             var vmax = this.model.get('max');
             if (this.model.get("_range")) {
-                // range case
-                // ranges can be expressed either "val-val" or "val:val" (+spaces)
-                var match = this._range_regex.exec(text);
-                if (match) {
-                    var values = [this._parse_value(match[1]),
-                                  this._parse_value(match[2])];
-                    // reject input where NaN or lower > upper
-                    if (isNaN(values[0]) ||
-                        isNaN(values[1]) ||
-                        (values[0] > values[1])) {
-                        this.$readout.text(this.model.get('value').join('-'));
-                    } else {
-                        // clamp to range
-                        values = [Math.max(Math.min(values[0], vmax), vmin),
-                                  Math.max(Math.min(values[1], vmax), vmin)];
-
-                        if ((values[0] != this.model.get('value')[0]) ||
-                            (values[1] != this.model.get('value')[1])) {
-                            this.$readout.text(values.join('-'));
-                            this.model.set('value', values, {updated_view: this});
-                            this.touch();
-                        } else {
-                            this.$readout.text(this.model.get('value').join('-'));
-                        }
-                    }
+                // reject input where NaN or lower > upper
+                if (value === null ||
+                    isNaN(value[0]) ||
+                    isNaN(value[1]) ||
+                    (value[0] > value[1])) {
+                    this.$readout.text(this.valueToString(this.model.get('value')));
                 } else {
-                    this.$readout.text(this.model.get('value').join('-'));
+                    // clamp to range
+                    value = [Math.max(Math.min(value[0], vmax), vmin),
+                              Math.max(Math.min(value[1], vmax), vmin)];
+
+                    if ((value[0] != this.model.get('value')[0]) ||
+                        (value[1] != this.model.get('value')[1])) {
+                        this.$readout.text(this.valueToString(value));
+                        this.model.set('value', value, {updated_view: this});
+                        this.touch();
+                    } else {
+                        this.$readout.text(this.valueToString(this.model.get('value')));
+                    }
                 }
             } else {
+                
                 // single value case
-                var value = this._parse_value(text);
                 if (isNaN(value)) {
-                    this.$readout.text(this.model.get('value'));
+                    this.$readout.text(this.valueToString(this.model.get('value')));
                 } else {
                     value = Math.max(Math.min(value, vmax), vmin);
 
                     if (value != this.model.get('value')) {
-                        this.$readout.text(value);
+                        this.$readout.text(this.valueToString(value));
                         this.model.set('value', value, {updated_view: this});
                         this.touch();
                     } else {
-                        this.$readout.text(this.model.get('value'));
+                        this.$readout.text(this.valueToString(this.model.get('value')));
                     }
                 }
             }
@@ -253,13 +286,10 @@ define([
 
         _range_regex: /^\s*([+-]?\d+)\s*[-:]\s*([+-]?\d+)/,
 
+        /**
+         * Called when the slider value is changing.
+         */
         handleSliderChange: function(e, ui) { 
-            /**
-             * Called when the slider value is changed.
-             *
-             * Calling model.set will trigger all of the other views of the 
-             * model to update.
-             */
             var actual_value;
             if (this.model.get("_range")) {
                 actual_value = ui.values.map(this._validate_slide_value);
@@ -268,6 +298,27 @@ define([
                 actual_value = this._validate_slide_value(ui.value);
                 this.$readout.text(actual_value);
             }
+            
+            // Only persist the value while sliding if the continuous_update
+            // trait is set to true.
+            if (this.model.get('continuous_update')) {
+                this.handleSliderChanged(e, ui);
+            }            
+        },
+        
+        /**
+         * Called when the slider value has changed.
+         *
+         * Calling model.set will trigger all of the other views of the 
+         * model to update.
+         */
+        handleSliderChanged: function(e, ui) {
+            var actual_value;
+            if (this.model.get("_range")) {
+                actual_value = ui.values.map(this._validate_slide_value);
+            } else {
+                actual_value = this._validate_slide_value(ui.value);
+            }
             this.model.set('value', actual_value, {updated_view: this});
             this.touch();
         },
@@ -299,7 +350,23 @@ define([
                 .addClass('form-control')
                 .addClass('widget-numeric-text')
                 .appendTo(this.$el);
+                
+            this.listenTo(this.model, 'change:description', function(sender, value) {
+                this.updateDescription();
+            }, this);
+                
             this.update(); // Set defaults.
+            this.updateDescription();
+        },
+        
+        updateDescription: function() {
+            var description = this.model.get('description');
+            if (description.length === 0) {
+                this.$label.hide();
+            } else {
+                this.typeset(this.$label, description);
+                this.$label.show();
+            }
         },
         
         update : function(options){
@@ -320,14 +387,6 @@ define([
                 } else {
                     this.$textbox.removeAttr('disabled');
                 }
-
-                var description = this.model.get('description');
-                if (description.length === 0) {
-                    this.$label.hide();
-                } else {
-                    this.typeset(this.$label, description);
-                    this.$label.show();
-                }
             }
             return IntTextView.__super__.update.apply(this);
         },
@@ -424,14 +483,31 @@ define([
                     'bottom': 0, 'left': 0,
                 })
                 .appendTo(this.$progress);
-            this.update(); // Set defaults.
-
+            
+            // Set defaults.
+            this.update(); 
+            this.updateDescription();
+            
             this.listenTo(this.model, 'change:bar_style', function(model, value) {
                 this.update_bar_style();
             }, this);
+            this.listenTo(this.model, 'change:description', function(sender, value) {
+                this.updateDescription();
+            }, this);
+            
             this.update_bar_style('');
         },
         
+        updateDescription: function() {
+            var description = this.model.get('description');
+            if (description.length === 0) {
+                this.$label.hide();
+            } else {
+                this.typeset(this.$label, description);
+                this.$label.show();
+            }    
+        },
+        
         update : function(){
             /**
              * Update the contents of this view
@@ -465,13 +541,6 @@ define([
                     'height': percent + '%',
                 });
             }
-            var description = this.model.get('description');
-            if (description.length === 0) {
-                this.$label.hide();
-            } else {
-                this.typeset(this.$label, description);
-                this.$label.show();
-            }
             return ProgressView.__super__.update.apply(this);
         }, 
 
