@@ -24,6 +24,7 @@ from traitlets import (
 from jupyter_core.application import base_flags, base_aliases
 
 from .blocking import BlockingKernelClient
+from .restarter import KernelRestarter
 from . import KernelManager, tunnel_to_kernel, find_connection_file, connect
 from .kernelspec import NoSuchKernel
 from .session import Session
@@ -47,11 +48,15 @@ app_flags = {
 }
 app_flags.update(boolean_flag(
     'confirm-exit', 'JupyterConsoleApp.confirm_exit',
-    """Set to display confirmation dialog on exit. You can always use 'exit' or 'quit',
-       to force a direct exit without any confirmation.
+    """Set to display confirmation dialog on exit. You can always use 'exit' or
+       'quit', to force a direct exit without any confirmation. This can also
+       be set in the config file by setting
+       `c.JupyterConsoleApp.confirm_exit`.
     """,
     """Don't prompt the user when exiting. This will terminate the kernel
        if it is owned by the frontend, and leave it alive if it is external.
+       This can also be set in the config file by setting
+       `c.JupyterConsoleApp.confirm_exit`.
     """
 ))
 flags.update(app_flags)
@@ -80,7 +85,7 @@ aliases.update(app_aliases)
 # Classes
 #-----------------------------------------------------------------------------
 
-classes = [KernelManager, Session]
+classes = [KernelManager, KernelRestarter, Session]
 
 class JupyterConsoleApp(ConnectionFileMixin):
     name = 'jupyter-console-mixin'
@@ -230,11 +235,11 @@ class JupyterConsoleApp(ConnectionFileMixin):
         self.shell_port, self.iopub_port, self.stdin_port, self.hb_port = newports
         
         cf = self.connection_file
-        base,ext = os.path.splitext(cf)
-        base = os.path.basename(base)
-        self.connection_file = os.path.basename(base)+'-ssh'+ext
+        root, ext = os.path.splitext(cf)
+        self.connection_file = root + '-ssh' + ext
+        self.write_connection_file() # write the new connection file
         self.log.info("To connect another client via this tunnel, use:")
-        self.log.info("--existing %s" % self.connection_file)
+        self.log.info("--existing %s" % os.path.basename(self.connection_file))
     
     def _new_connection_file(self):
         cf = ''
