@@ -11,6 +11,7 @@ from __future__ import print_function
 
 import logging
 import signal
+import sys
 
 from traitlets import (
     Dict, Any
@@ -23,7 +24,7 @@ from jupyter_client.consoleapp import (
         JupyterConsoleApp, app_aliases, app_flags,
     )
 
-from jupyter_console.interactiveshell import ZMQTerminalInteractiveShell
+from jupyter_console.ptshell import ZMQTerminalInteractiveShell
 from jupyter_console import __version__
 
 #-----------------------------------------------------------------------------
@@ -52,7 +53,6 @@ aliases = dict(base_aliases)
 frontend_aliases = dict(app_aliases)
 # load updated frontend flags into full dict
 aliases.update(frontend_aliases)
-aliases['colors'] = 'InteractiveShell.colors'
 
 # get flags&aliases into sets, and remove a couple that
 # shouldn't be scrubbed from backend flags:
@@ -92,9 +92,9 @@ class ZMQTerminalIPythonApp(JupyterApp, JupyterConsoleApp):
     aliases = Dict(aliases)
     frontend_aliases = Any(frontend_aliases)
     frontend_flags = Any(frontend_flags)
-    
+
     subcommands = Dict()
-    
+
     force_interact = True
 
     def parse_command_line(self, argv=None):
@@ -106,7 +106,6 @@ class ZMQTerminalIPythonApp(JupyterApp, JupyterConsoleApp):
         # relay sigint to kernel
         signal.signal(signal.SIGINT, self.handle_sigint)
         self.shell = ZMQTerminalInteractiveShell.instance(parent=self,
-                        display_banner=False,
                         manager=self.kernel_manager,
                         client=self.kernel_client,
         )
@@ -121,7 +120,7 @@ class ZMQTerminalIPythonApp(JupyterApp, JupyterConsoleApp):
             if self.kernel_manager:
                 self.kernel_manager.interrupt_kernel()
             else:
-                self.shell.write_err('\n')
+                print("", file=sys.stderr)
                 error("Cannot interrupt kernels we didn't start.\n")
         else:
             # raise the KeyboardInterrupt if we aren't waiting for execution,
@@ -144,7 +143,7 @@ class ZMQTerminalIPythonApp(JupyterApp, JupyterConsoleApp):
         self.shell.show_banner()
         # Make sure there is a space below the banner.
         if self.log_level <= logging.INFO: print()
-    
+
     def start(self):
         # JupyterApp.start dispatches on NoStart
         super(ZMQTerminalIPythonApp, self).start()
